#!/bin/bash
# ----------------------------------------------------------------------------
# /tmp/install.sh - teamspeak3 installation
#
# Creation   : 2010-01-26 christian
# Last update: $Id: install.sh 37 2010-08-04 11:08:54Z root $
#
# Copyright (c) 2010 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# set package name
packageName=teamspeak3

# set some variables
package_pos='99'

GroupID=9987
UserID=9987
GROUPNAME=tss3
USER=teamspeak3

# ----------------------------------------------------------------------------
# Setup step 1
# ----------------------------------------------------------------------------
if [ -z "${EISFAIR_SYSTEM}" ]
then
    # get eisfair system-type
    . /var/install/include/check-eisfair-version
fi

# Setup system specific values
case "${EISFAIR_SYSTEM}" in
    eisfair-1)  # eisfair-1 code
        needed_kernel='1.2.0'
        ### check kernel version
        if [ ! -f /var/install/bin/check-version ] || [ `/var/install/bin/check-version eiskernel $needed_kernel` = "new" ]
        then
            clrhome
            mecho
            mecho -error "WARNING                                   "
            mecho -error "Your kernel is too old, you need at least "
            mecho -error "the kernel package 1.20.0 or above!      "
            mecho
            mecho -warn  "Sorry, teamspeak3 server can't start until you fix the issues above"
            mecho
            anykey
            exit 1
        fi
        ;;
esac


# ----------------------------------------------------------------------------
# add user/group
# ----------------------------------------------------------------------------
# add group tss if nessesary
mecho -n -info "Creating group ${GROUPNAME} ... "
if [ `grep ${GROUPNAME} /etc/group | wc -l` -eq 0 ]
then
    /var/install/bin/add-group ${GROUPNAME} ${GroupID}
    mecho -info "done"
else
    mecho -info "group exists"
fi

# add user teamspeak if nessesary
mecho -n -info "Creating user ${USER} ... "
if [ `grep ${USER} /etc/passwd | wc -l` -eq 0 ]
then
    GroupID=`grep ${GROUPNAME} /etc/group | cut -d":" -f3`
    /var/install/bin/add-user -d "${USER}" "" "${UserID}" "${GroupID}" "${packageName} user" "/home/.${packageName}" "/bin/sh"
    mecho -info "done"
else
    mecho -info "user exsist"
fi

#mecho "Setting access rights for teamspeak3 ..."
chmod u+x /usr/local/${packageName}/ts3server_linux_x86
chown -R teamspeak3:tss3 /usr/local/teamspeak3


# ----------------------------------------------------------------------------
# install startup/stop-scripts
# ----------------------------------------------------------------------------
package_kill_pos=`/usr/bin/expr 100 - ${package_pos}`
if [ "${package_kill_pos}" -lt 10 ]
then
    package_kill_pos='0'${package_kill_pos}
fi
package_start='S'${package_pos}${packageName}
package_kill='K'${package_kill_pos}${packageName}
ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_start}
ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_kill}

# ----------------------------------------------------------------------------
# Add menu
# ----------------------------------------------------------------------------
/var/install/bin/add-menu setup.services.menu setup.services.${packageName}.menu "${packageName}"

# ----------------------------------------------------------------------------
# Create default config
# ----------------------------------------------------------------------------

/var/install/config.d/${packageName}-update.sh

# ----------------------------------------------------------------------------
# Start configuration editor if necessary
# ----------------------------------------------------------------------------
. /etc/config.d/${packageName}
if [ "${START_TEAMSPEAK3}" == 'no' ]
then
    /var/install/bin/edit -apply ${packageName} "Edit ${packageName} configuration"
else
    /var/install/config.d/${packageName}.sh --quiet
fi


exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
