#!/bin/bash
# ----------------------------------------------------------------------------
# /var/install/config.d/teamspeak3-update.sh - paramater update script
#
# Creation   : 2010-01-26 christian
# Last update: $Id: teamspeak3-update.sh 37 2010-08-04 11:08:54Z root $
#
# Copyright (c) 2010 christian Richter, <richterch(at)gmx(dot)de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/teamspeak3-update-trace$$.log
#set -x

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib

# set packages name
packageName=teamspeak3

# ----------------------------------------------------------------------------
# Set the default values for configuration
# ----------------------------------------------------------------------------
START_TEAMSPEAK3='no'
TEAMSPEAK3_LICENSEPATH="/usr/local/${packageName}"

TEAMSPEAK3_ADVANCED='no'
TEAMSPEAK3_MACHINE_ID=''
TEAMSPEAK3_VOICE_PORT='9987'
TEAMSPEAK3_VOICE_IP='0.0.0.0'
TEAMSPEAK3_FILETRANSFER_PORT='30033'
TEAMSPEAK3_FILETRANSFER_IP='0.0.0.0'
TEAMSPEAK3_QUERY_PORT='10011'
TEAMSPEAK3_QUERY_IP='0.0.0.0'
TEAMSPEAK3_CLEAR_DB='no'

TEAMSPEAK3_USE_MYSQL='no'
TEAMSPEAK3_MYSQL_HOST='127.0.0.1'
TEAMSPEAK3_MYSQL_PORT='3306'
TEAMSPEAK3_MYSQL_USER='tss3'
TEAMSPEAK3_MYSQL_PASS='tss3'
TEAMSPEAK3_MYSQL_DB='tss3'
TEAMSPEAK3_MYSQL_SOCKET=''

TEAMSPEAK3_LOG_PATH='/var/log'
TEAMSPEAK3_LOGROTATE='no'
TEAMSPEAK3_LOGROTATE_COUNT='3'
TEAMSPEAK3_LOGROTATE_INTERVAL='weekly'

TEAMSPEAK3_UPDATE_CHECK='yes'
TEAMSPEAK3_UPDATE_MAILADDR='foo@bar'
TEAMSPEAK3_UPDATE_MAIL_SUBJECT='New Teamspeak3 update avaiable'
TEAMSPEAK3_UPDATE_INTERVAL='23 12 1 * *'

# ----------------------------------------------------------------------------
# Read old configuration and rename old variables
# ----------------------------------------------------------------------------
renameOldVariables()
{
    # read old values
    if [ -f /etc/config.d/${packageName} ]
    then
        . /etc/config.d/${packageName}
    fi
}

# ----------------------------------------------------------------------------
# Write config and default files
# ----------------------------------------------------------------------------
makeConfigFile()
{
    internal_conf_file=${1}
    {
    # ------------------------------------------------------------------------
    printgpl -conf ${packageName} "2010-02-08" "christian"
    # ------------------------------------------------------------------------


    # ------------------------------------------------------------------------
    printgroup "Basic configuration"
    # ------------------------------------------------------------------------
    printvar "START_TEAMSPEAK3" "Use: yes or no"
    printvar "TEAMSPEAK3_LICENSEPATH" "If you have a license, type in path here"

    # ------------------------------------------------------------------------
    printcustomgroup "Advanced Configuration" <<EOFG
changes here makes it necessary to install additional packages.
You don't need to change anything unless you know what you do.
EOFG
    # ------------------------------------------------------------------------
    printvar "TEAMSPEAK3_ADVANCED" "Use: yes or no"
    printvar "TEAMSPEAK3_MACHINE_ID" "Mashine ID: Could be empty"
    printvar "TEAMSPEAK3_VOICE_PORT" "Portnumber for Voice"
    printvar "TEAMSPEAK3_VOICE_IP" "Bind on which IP"
    printvar "TEAMSPEAK3_FILETRANSFER_PORT" "Port for Filetransfers"
    printvar "TEAMSPEAK3_FILETRANSFER_IP" "Bind on which IP"
    printvar "TEAMSPEAK3_QUERY_PORT" "Portnumber for the serverquery"
    printvar "TEAMSPEAK3_QUERY_IP" "Query IP-Adress"
    printvar "TEAMSPEAK3_CLEAR_DB" "Clear the database?"

    # ------------------------------------------------------------------------
    printcustomgroup "Database Settings" <<EOFG
If you want to run your TS3 Server on a MySQL-Database-Server, you must
change the following values.
Please note that changes here makes it necessary to install
additional packages.
EOFG
    # ------------------------------------------------------------------------
    printvar "TEAMSPEAK3_USE_MYSQL" "Use MySQL Database: yes or no"
    printvar "TEAMSPEAK3_MYSQL_HOST" "MySQL host: (127.0.0.1)"
    printvar "TEAMSPEAK3_MYSQL_PORT" "Port of MySQL-Server"
    printvar "TEAMSPEAK3_MYSQL_USER" "Username for TS3-Database"
    printvar "TEAMSPEAK3_MYSQL_PASS" "Password for TS3-Database"
    printvar "TEAMSPEAK3_MYSQL_DB" "Name of TS3 Database"
    printvar "TEAMSPEAK3_MYSQL_SOCKET" "Socket"

    #-------------------------------------------------------------------------
    printgroup "Log Handling"
    #-------------------------------------------------------------------------
    printvar "TEAMSPEAK3_LOG_PATH"           "Path where logs are saved"
    printvar "TEAMSPEAK3_LOGROTATE"          "Use logrotate: yes or no"
    printvar "TEAMSPEAK3_LOGROTATE_COUNT"    "How many logs would be backuped"
    printvar "TEAMSPEAK3_LOGROTATE_INTERVAL" "Interval: daily, weekly or monthly"

    #-------------------------------------------------------------------------
    printgroup "Update Handling"
    #-------------------------------------------------------------------------
    printvar "TEAMSPEAK3_UPDATE_CHECK"        "Do you want to check for updates"
    printvar "TEAMSPEAK3_UPDATE_MAILADDR"     "mailaddress"
    printvar "TEAMSPEAK3_UPDATE_MAIL_SUBJECT" "mailsubject"
    printvar "TEAMSPEAK3_UPDATE_INTERVAL"     "cronjob"

    # ------------------------------------------------------------------------
    printend
    # ------------------------------------------------------------------------

    } > ${internal_conf_file}
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}

# ----------------------------------------------------------------------------
# Create the check.d file
# ----------------------------------------------------------------------------
makeCheckFile()
{
    printgpl -check ${packageName} '2010-01-26' 'christian' >/etc/check.d/${packageName}
    cat >> /etc/check.d/${packageName} <<EOFG
# Variable                        OPT_VARIABLE         VARIABLE_N           VALUE
START_TEAMSPEAK3                  -                    -                    YESNO
TEAMSPEAK3_LICENSEPATH            START_TEAMSPEAK3     -                    E_ABS_PATH

TEAMSPEAK3_ADVANCED               START_TEAMSPEAK3     -                    YESNO
TEAMSPEAK3_MACHINE_ID             TEAMSPEAK3_ADVANCED  -                    ENOBLANK
TEAMSPEAK3_VOICE_PORT             TEAMSPEAK3_ADVANCED  -                    PORT
TEAMSPEAK3_VOICE_IP               TEAMSPEAK3_ADVANCED  -                    IPADDR
TEAMSPEAK3_FILETRANSFER_PORT      TEAMSPEAK3_ADVANCED  -                    PORT
TEAMSPEAK3_FILETRANSFER_IP        TEAMSPEAK3_ADVANCED  -                    IPADDR
TEAMSPEAK3_QUERY_PORT             TEAMSPEAK3_ADVANCED  -                    PORT
TEAMSPEAK3_QUERY_IP               TEAMSPEAK3_ADVANCED  -                    IPADDR
TEAMSPEAK3_CLEAR_DB               TEAMSPEAK3_ADVANCED  -                    YESNO

TEAMSPEAK3_USE_MYSQL              START_TEAMSPEAK3     -                    YESNO
TEAMSPEAK3_MYSQL_HOST             TEAMSPEAK3_USE_MYSQL -                    IPADDR
TEAMSPEAK3_MYSQL_PORT             TEAMSPEAK3_USE_MYSQL -                    PORT
TEAMSPEAK3_MYSQL_USER             TEAMSPEAK3_USE_MYSQL -                    ENOBLANK
TEAMSPEAK3_MYSQL_PASS             TEAMSPEAK3_USE_MYSQL -                    PASSWD
TEAMSPEAK3_MYSQL_DB               TEAMSPEAK3_USE_MYSQL -                    ENOBLANK
TEAMSPEAK3_MYSQL_SOCKET           TEAMSPEAK3_USE_MYSQL -                    ENOBLANK

TEAMSPEAK3_LOG_PATH               START_TEAMSPEAK3     -                    ABS_PATH
TEAMSPEAK3_LOGROTATE              START_TEAMSPEAK3     -                    YESNO
TEAMSPEAK3_LOGROTATE_COUNT        TEAMSPEAK3_LOGROTATE -                    NUMERIC
TEAMSPEAK3_LOGROTATE_INTERVAL     TEAMSPEAK3_LOGROTATE -                    TEAMSPEAK3_CHOOSE_LOGROTATE_INTERVAL_CUI

TEAMSPEAK3_UPDATE_CHECK           START_TEAMSPEAK3     -                    YESNO
TEAMSPEAK3_UPDATE_MAILADDR        TEAMSPEAK3_UPDATE_CHECK  -                MAILADDR
TEAMSPEAK3_UPDATE_MAIL_SUBJECT    TEAMSPEAK3_UPDATE_CHECK  -                NONE
TEAMSPEAK3_UPDATE_INTERVAL        TEAMSPEAK3_UPDATE_CHECK  -                CRONTAB


EOFG

    # Set rights for check.d file
    chmod 0600 /etc/check.d/${packageName}
    chown root /etc/check.d/${packageName}

    printgpl -check_exp ${packageName} '2010-01-26' 'christian' >/etc/check.d/${packageName}.exp
    cat >> /etc/check.d/${packageName}.exp <<EOFG
TEAMSPEAK3_CHOOSE_LOGROTATE_INTERVAL_CUI = 'daily|weekly|monthly'
                                         : 'Only "daily", "weekly" or "monthly" allowed'

EOFG

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${packageName}.exp
    chown root /etc/check.d/${packageName}.exp

#    printgpl -check_ext ${packageName} '2010-01-26' 'christian' >/etc/check.d/${packageName}.ext
#    cat >> /etc/check.d/${packageName}.ext <<EOFG
#
#
#EOFG

    # Set rights for check.ext file
#    chmod 0600 /etc/check.d/${packageName}.ext
#    chown root /etc/check.d/${packageName}.ext
}



# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
# Write default config file
if [ -f /etc/config.d/${packageName} ]
then
    mecho -info -n "Updating configuration."
else
    mecho -info -n "Creating configuration."
fi

makeConfigFile /etc/default.d/${packageName}

# Update from old version
mecho -info -n "."
renameOldVariables

# Write new config file
mecho -info -n "."
makeConfigFile /etc/config.d/${packageName}

# Write check.d file
mecho -info -n "."
makeCheckFile

mecho -info " Finished."

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
